@@ -1348,6 +1348,11 @@ start_login(host, autologin, name)
 	if (require_SecurID)
 		argv = addarg(argv, "-s");
 #endif
+	if(*name=='-')
+	{
+		syslog(LOG_ERR, "Attempt to login with an option!");
+		name="";
+	}
 #if	defined (AUTHENTICATE)
 	if (auth_level >= 0 && autologin == AUTH_VALID) {
 # if	!defined(NO_LOGIN_F)
@@ -1357,6 +1362,12 @@ start_login(host, autologin, name)
 	} else
 #endif
 	if (getenv("USER")) {
+		if(*getenv("USER")=='-')
+		{
+			write(1,"I don't hear you!\r\n",19);
+			syslog(LOG_ERR,"Attempt to login with an option!");
+			exit(1);
+		}
 		argv = addarg(argv, getenv("USER"));
 #if	defined(CRAY) && defined(NO_LOGIN_P)
 		{
